/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Contact Information:
 * Swarco Traffic Systems GmbH
 * Entwicklung
 * Adolf-Dambach-Strae
 * D-76571 Gaggenau
 * Phone: +49 (0)7225-64-0
 * Fax: +49 (0)7225-64-300
 * mailto: office.sts@swarco.de
 */

package de.bsvrz.ste.stealgsba.algorithmen.lib;

import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;

import de.bsvrz.dav.daf.main.ClientDavConnection;
import de.bsvrz.dav.daf.main.ClientDavInterface;
import de.bsvrz.dav.daf.main.ClientReceiverInterface;
import de.bsvrz.dav.daf.main.DataDescription;
import de.bsvrz.dav.daf.main.ReceiveOptions;
import de.bsvrz.dav.daf.main.ReceiverRole;
import de.bsvrz.dav.daf.main.ResultData;
import de.bsvrz.dav.daf.main.config.Aspect;
import de.bsvrz.dav.daf.main.config.AttributeGroup;
import de.bsvrz.dav.daf.main.config.DynamicObject;
import de.bsvrz.dav.daf.main.config.SystemObject;

/**
 * Kommentar 
 *
 * @version $Revision: 1.2 $ / $Date: 2012/07/23 06:02:38 $ / ($Author: Asal $)
 *
 * @author Swarco Traffic Systems GmbH
 * @author Rolf Asal
 *
 */
public class SituationAnalyseUfdmsEmpfang implements ClientReceiverInterface
{
	private ClientDavConnection m_connection;
	private DynamicObject m_objekt;
	
  /**
   * Definition der Attributgruppe
   */
  private String m_atg = "atg.sswSbaUeSituationAnalyseUfdms";
  
  /**
   * bentigter Aspekt
   */
  private String m_asp = "asp.analyse";
  /**
   * Liste zur Verwaltung der Listener
   */  
  private List<IUfdmsNeueDatenListener> m_angemeldeteListener = new LinkedList<IUfdmsNeueDatenListener>();

  private ResultData m_daten;
  
	public SituationAnalyseUfdmsEmpfang(ClientDavInterface connection, DynamicObject objekt)
	{
		m_connection = (ClientDavConnection)connection;
		m_objekt = objekt;
		
    anmeldeLeseDaV (m_objekt.getPid(), m_atg, m_asp, ReceiverRole.receiver());

	}

  /**
   * Methode die das Objekt mit der PID objPid beim Datenverteiler anmeldet zum
   * Lesen der Attibutgruppe atgPid unter dem Aspekt aspPid. 
   * @param objPid Pid des Objekts 
   * @param atgPid Attributgruppe die angemeldet werden soll
   * @param aspPid Apekt der angemeldet werden soll
   * @param role Rolle des Empfngers (siehe stauma.dav.clientside.ReceiveOptions)
   */
  private void anmeldeLeseDaV (String objPid, String atgPid, String aspPid, ReceiverRole role)
  {
    String buffer = "Anmelden am DaV (Lesen): " + objPid + " " + atgPid + "  " + aspPid;
        
    AttributeGroup atg = m_connection.getDataModel().getAttributeGroup(atgPid);
    Aspect asp = m_connection.getDataModel().getAspect(aspPid);

    DataDescription dd = new DataDescription(atg, asp);

    SystemObject obj = m_connection.getDataModel().getObject(objPid); 

    m_connection.subscribeReceiver(this, obj, dd, ReceiveOptions.normal(), role);
  }

	@Override
	public void update(ResultData[] results)
	{
		for (ResultData resultData : results)
		{
      if (resultData.getDataDescription().getAttributeGroup().getPid().equals(m_atg))
      {
        
        // Absender feststellen
        
        String absenderPid = resultData.getObject().getPid();

//        System.out.println("SituationAnalyseMq von Objekt " + absenderPid + " erhalten");
        
        if (m_objekt.getPid().equals(absenderPid))
        {
	        if (resultData.hasData())
	        {
	          m_daten = resultData;
	          
	          benachrichtigeListener(resultData);	          
	        }
        }
      }			
		}		
	}

  //----------------------------------------------------------------------------------------------
  // Listener Funktionalitten
  //----------------------------------------------------------------------------------------------

  /**
   * Methode zum Hinzufgen eines Listeners
   * @param listener Listener der hinzugefgt werden soll
   */
  public void addListener (IUfdmsNeueDatenListener listener)
  {
  	if (!m_angemeldeteListener.contains(listener))
  		m_angemeldeteListener.add( listener );
  }
 
  /**
   * Methode zum Entfernen eines Listeners
   * @param listener Listener der entfernt werden soll
   */
  public void removeListener (IUfdmsNeueDatenListener listener)
  {
    m_angemeldeteListener.remove( listener );
  }
 
  /**
   * Methode mit der die Klasse alle bei ihr angemeldeten Listener
   * ber die nderung der Selektion informiert.
   */
  private void benachrichtigeListener (ResultData rdata)
  {
    Iterator<IUfdmsNeueDatenListener> it = m_angemeldeteListener.iterator();
    while (it.hasNext())
    {
      IUfdmsNeueDatenListener l = it.next();
      
      SituationAnalyseUfdms analyse = new SituationAnalyseUfdms(rdata);
      
      l.neueDatenSituationAnalyseUfdms(analyse);
    }
  }

	/**
	 * Gibt den Datensatz der empfangenen Daten zurck.
	 *  
	 * @return Datensatz der empfangenen Daten.
	 */
	public ResultData getDaten()
	{
		return m_daten;
	}

}
