/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Contact Information:
 * Swarco Traffic Systems GmbH
 * Entwicklung
 * Adolf-Dambach-Strae
 * D-76571 Gaggenau
 * Phone: +49 (0)7225-64-0
 * Fax: +49 (0)7225-64-300
 * mailto: office.sts@swarco.de
 */

package de.bsvrz.ste.stealgsba.algorithmen.lib;

import de.bsvrz.dav.daf.main.Data;
import de.bsvrz.dav.daf.main.ResultData;

/**
 * Diese Klasse dient zum Speichern der Daten die ber die Attributgruppe 'atg.strfallZustand'
 * ber den Datenverteiler empfangen wurden.<p>
 * 
 * ber Getter und Setter kann auf die Daten zugegriffen werden.
 *
 * @version $Revision: 1.3 $ / $Date: 2015/08/26 13:57:08 $ / ($Author: Asal $)
 *
 * @author Swarco Traffic Systems GmbH
 * @author Rolf Asal
 *
 */
public class StoerfallZustand
{
	/**
	 * Wert der Verkehrssituation.
	 */
	private int m_situation;
	/**
	 * Gteindex.
	 */
	private float m_guete;
	
	/**
	 * Default-Konstruktor ohne weitere Funktion.
	 */
	public StoerfallZustand()
	{		
	}

	/**
	 * Konstruktor mit bernahme der bergebenen Daten.
	 */
	public StoerfallZustand(ResultData rdata)	
	{
		setDaten(rdata);
	}
	
	/**
	 * bernimmt die bergebenen Daten in die interne Struktur.
	 * 
	 * @param rdata Datensatz Strfallzustand.
	 */
	public void setDaten(ResultData rdata)
	{
		if (rdata != null)
		{
			Data data = rdata.getData();
			if (data != null)
			{
    		m_situation = data.getUnscaledValue("Situation").intValue();
    		
    		if (data.getItem("Gte").getScaledValue("Index").isState())
    		{
    			m_guete = data.getItem("Gte").getUnscaledValue("Index").intValue();    			
    		}
    		else
    		{
    			m_guete = data.getItem("Gte").getScaledValue("Index").floatValue();
    		}
			}
			else
			{
				init();
			}
		}
	}

	/**
	 * Initialisiert die interne Struktur auf <code>nicht ermittelbar</code>.
	 */
	public void init()
	{
		m_situation = -1;
		m_guete = -1;
	}

	/**
	 * Gibt zurck, ob aktuelle Daten empfangen wurden.
	 * 
	 * @return true wenn strfallzustand vorhanden, ansonsten false;
	 */
	public boolean hasDatenErhalten()
	{
		if ((m_situation == -1) &&
				(m_guete == -1))
		{
			return false;
		}
		
		return true;
	}

	/* (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	public String toString()
	{
		StringBuffer string = new StringBuffer();
		
		string.append("Situation  : " + m_situation + " Gte " + m_guete);
		
		return string.toString();
	}

	/**
	 * Gibt den Wert der Verkehrssituation zurck.
	 * @return Wert der Verkehrssituation.
	 */
	public int getSituation()
	{
		return m_situation;
	}

	/**
	 * Setzt den Wert der Verkehrssituation.
	 * @param situation zu setzender Wert der Verkehrssituation.
	 */
	public void setSituation(int situation)
	{
		m_situation = situation;
	}

	/**
	 * Gibt den Gteindex zurck.
	 * @return Gteindex.
	 */
	public float getGuete()
	{
		return m_guete;
	}

	/**
	 * Setzt den Gteindex.
	 * @param guete zu setzender Gteindex.
	 */
	public void setGuete(float guete)
	{
		m_guete = guete;
	}
}
